summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJean-Philippe NOEL2013-02-20 13:18:24 +0100
committerJean-Philippe NOEL2013-02-21 11:59:50 +0100
commit5815c4f057cce14a47064fc9129888a40de602e5 (patch)
tree00713f30490c07a713aef3c3af0663d91d9ceeed
parentc20b9f666d8c9dfd7a112361cb0147a662ebb44d (diff)
validation/test/P2P_throughput: clean the config, refs #3777
-rw-r--r--validation/test/P2P_throughput/config.py56
1 files changed, 28 insertions, 28 deletions
diff --git a/validation/test/P2P_throughput/config.py b/validation/test/P2P_throughput/config.py
index 34f105d18c..cd0a17ea36 100644
--- a/validation/test/P2P_throughput/config.py
+++ b/validation/test/P2P_throughput/config.py
@@ -9,12 +9,12 @@
"get_CE_stats":True,
# CE stats which difference, before and after each serie of measurements,
# is displayed in the report
- "displayed_CE_stats": ["BLE",
- "Restart BER",
- "Restart PB error rate",
- "Restart peer request",
- "Restart tone map update",
- "Restart ber margin update"],
+ "displayed_CE_stats":["BLE",
+ "Restart BER",
+ "Restart PB error rate",
+ "Restart peer request",
+ "Restart tone map update",
+ "Restart ber margin update"],
# True|False
# If True, the measurements are reset, made and then the report is generated
# If False, the report is generated from the previous measurements
@@ -25,14 +25,14 @@
# ["a_b_uni"|"b_a_uni"|"bi"]
# see iperf.measurement_specs() for the meaning of the values
"curves":["a_b_uni", "b_a_uni", "bi"]},
- "SNR": {
- "values":numpy.arange(35, -10, -5).tolist(),
+ "SNR":{
+ "values":numpy.arange(40, -10, -5).tolist(),
"duration_s":20,
# ["a_b_uni"|"b_a_uni"|"bi"]
# see iperf.measurement_specs() for the meaning of the values
"curves":["a_b_uni", "b_a_uni"]},
"SJR":{
- "values":numpy.arange(0, -55, -5).tolist(),
+ "values":numpy.arange(10, -45, -5).tolist(),
"duration_s":20,
# ["a_b_uni"]
# see iperf.measurement_specs() for the meaning of the values
@@ -96,7 +96,7 @@
],
# Duration after the channel modification during which we generate traffic
# to let the CE converge
- "ce_sync_time_s":2,
+ "ce_sync_time_s":10,
# Directory where the images and the report are generated
# It is recommended to indicate in this parameter all the
# elements identifying the test, including the software version and the name
@@ -107,7 +107,7 @@
# - (2, 28) in AV
# - (2, 35) in EoC-300
# - (4, 70) in EoC-500
- "signal_band_mhz":(1, 38),
+ "signal_band_mhz":(2, 35),
# Peak Power Spectral Density
# This value depends on the boards and must be carefully measured.
# Typical values are given in the test report (see
@@ -122,35 +122,35 @@
# sjr_attenuator_attenuation_db must be set to a value lower than
# (55 - 38) dB = 17 dB and greater than 0 dB, as long as these values are
# compatible with the range of attenuation of the variable attenuator.
- "sjr_attenuator_attenuation_db": 29,
+ "sjr_attenuator_attenuation_db":29,
# Attenuation of each AMN
# In AV, it must normally be set to 6
# In EoC, no AMN should be used and it should normally be set to 0
- "amn_attenuation_db": 0,
+ "amn_attenuation_db":0,
# Signal attenuation on each side of the bench, to avoid any dazzling
# between the plugs. A typical value is 10.
- "signal_attenuation_db": 10,
+ "signal_attenuation_db":10,
# Attenuation of the T
# If there is a T, it must normally be set to 6.
# If there is no T, it must be set to 0.
- "t_attenuation_db": 6,
+ "t_attenuation_db":6,
# Waveform attenuation at the output of the generator
- "waveform_attenuation_db": 3,
+ "waveform_attenuation_db":3,
# (unidir, bidir) throughput targets for UDP tests
# Typical values are:
- # - (100, 85) in AV with an SPR310 and
- # - (142, 85) for EoC-300 with an SPK300g
- # - (300, 160) for EoC-500 with an SPK300g
- "udp_throughputs_mbits_per_sec": (142, 85),
+ # - (100, 85) in AV with an SPR310
+ # - (180, 95) for EoC-300 with an SPK300g
+ # - (300, 160) for EoC-500 with an MSK500
+ "udp_throughputs_mbits_per_sec":(180, 95),
# Configuration passed to the 'attenuator' module
- "attenuator" : {
+ "attenuator":{
"name":"att",
"buttons":{1:1, 2:2, 3:4, 4:4, 5:10, 6:20, 7:40, 8:0},
"user":"spidcom",
"host":"tursan"
},
# Configuration passed to the 'waveform_generator' module
- "waveform_generator" : {
+ "waveform_generator":{
"name":"gbf",
"user":"spidcom",
"host":"tursan",
@@ -158,15 +158,15 @@
"power_range_dbm":(-40, 24)
},
# Configuration passed to the 'power_strip' module
- "power_strip":{1: ("192.168.0.10", "admin", "anel")},
+ "power_strip":{1:("192.168.0.10", "admin", "anel")},
# Configuration passed to the 'spc300' module
"spc300":{
- "eth_netmask": "192.168.5.",
- "plc_netmask": None,
+ "eth_netmask":"192.168.5.",
+ "plc_netmask":None,
"plugs":
{
- (1, 1, "master"): ("100", None, None, "spk300g_eoc_master"),
- (1, 5, "slave"): ("101", None, None, "spk300g_eoc_slave")
+ (1, 1, "master"):("100", None, None, "SPK300g-revE"),
+ (1, 5, "slave"):("101", None, None, "SPK300g-revE")
}
},
# Configuration passed to the 'non_spc300' module
@@ -176,7 +176,7 @@
}
},
# Configuration passed to the 'iperf' module
- "iperf" : {
+ "iperf":{
"host_a":{"non_plc_ip_address":"tursan",
"user":"spidcom",
"plc_ip_address":"192.168.5.254",